summaryrefslogtreecommitdiffstats
path: root/src/include/kernel/devicesegment.H
diff options
context:
space:
mode:
Diffstat (limited to 'src/include/kernel/devicesegment.H')
-rw-r--r--src/include/kernel/devicesegment.H7
1 files changed, 4 insertions, 3 deletions
diff --git a/src/include/kernel/devicesegment.H b/src/include/kernel/devicesegment.H
index dcaf78af8..c300eedde 100644
--- a/src/include/kernel/devicesegment.H
+++ b/src/include/kernel/devicesegment.H
@@ -56,12 +56,13 @@ class DeviceSegment : public Segment
/**
* @brief Handle a page fault for a device address access
* @param i_task[in] - Task pointer to the task requiring the page
* @param i_addr[in] - 64-bit address needed to be paged
* @return bool - true: Page added to page table
* false: Not a valid address to be paged
*/
- bool handlePageFault(task_t* i_task, uint64_t i_addr);
+ bool handlePageFault(task_t* i_task, uint64_t i_addr, bool i_store);
/**
OpenPOWER on IntegriCloud
@@ -56,12 +56,13 @@ class DeviceSegment : public Segment
/**
* @brief Handle a page fault for a device address access
- * @param i_task[in] - Task pointer to the task requiring the page
- * @param i_addr[in] - 64-bit address needed to be paged
+ * @param[in] i_task - Task pointer to the task requiring the page
+ * @param[in] i_addr - 64-bit address needed to be paged
+ * @param[in] i_store - Fault was due to a store.
* @return bool - true: Page added to page table
* false: Not a valid address to be paged